@@ -452,6 +452,43 @@ class CropFaces:
     return result
 
   def cropBox1Head (self, imagePath, output, box, mode='AUTO'):
+    result = None
+    if isinstance(mode, list):
+      result = self.cropBox1HeadArray(imagePath, output, box, mode)
+    else:
+      result = self.cropBox1HeadStr(imagePath, output, box, mode)
+    return result
+
+  def cropBox1HeadArray (self, imagePath, output, box, mode=[1932, 2801, 200]):
+    result = None
+    original = Image.open(imagePath)
+
+    realwidth = mode[0]
+    realheight = mode[1]
+    septop = mode[2]
+
+    newleft = (box.left + (box.width / 2)) - (realwidth / 2)
+    newtop = box.top - septop
+    newright = newleft + realwidth
+    newbottom = newtop + realheight
+
+    newbox = BoxArea(newleft, newtop, newright, newbottom)
+
+    cropped = original.crop((newbox.left, newbox.top, newbox.right, newbox.bottom))
+
+    newFileFolder = os.path.dirname(imagePath)
+    oldFileName = os.path.basename(imagePath)
+    extIdx = oldFileName.rindex('.')
+    fileExt = oldFileName[extIdx+1:]
+    newFile = output
+    if newFile is None:
+      newFileName = oldFileName[0:extIdx] + '_orla' + '.' + fileExt
+      newFile = os.path.join(newFileFolder, newFileName)
+    cropped.save(newFile, "jpeg", quality=100, optimize=True, progressive=True)
+    result = newFile
+    return result
+
+  def cropBox1HeadStr (self, imagePath, output, box, mode='AUTO'):
     result = None
     original = Image.open(imagePath)
     '''
@@ -486,14 +523,31 @@ class CropFaces:
       fHead = 0.5
       fSide = 0.9
       fBottom = 0.6
-    if mode == 'MIDDLE':
+    elif mode == 'MIDDLE':
       fHead = 0.5
       fSide = 0.9
       fBottom = 0.8
-    if mode == 'FAR':
+    elif mode == 'FAR':
       fHead = 0.5
       fSide = 0.9
       fBottom = 1.2
+    elif mode == 'MODE1':
+      fHead = 0.7
+      fSide = 0.9
+      fBottom = 2.2
+    elif mode == 'MODE2':
+      fHead = 0.7
+      fSide = 1.0
+      fBottom = 2.5
+    elif mode == 'MODE3':
+      fHead = 0.85
+      fSide = 0.9
+      fBottom = 2.2
+    elif mode == 'MODE4':
+      fHead = 0.85
+      fSide = 1.0
+      fBottom = 2.5
+
     width = box.width
     height = box.height
 
@@ -525,6 +579,115 @@ class CropFaces:
         self.crop1Head(fullpath, mode)
         modeIdx += 1
 
+  def cropAgainMoreSquares (self, imagePath):
+    img = Image.open(imagePath)
+    size = img.width
+    if size > 700:
+      newsize = int(size / 2)
+      newsize = int(newsize * 1.20)
+      newsize2 = int(size * 0.80)
+      offset2 = int(size * 0.10)
+      
+      exif = img.info['exif'] if 'exif' in img.info else None
+
+      self.saveCrop(img.crop((offset2, offset2, newsize2, newsize2)), imagePath, 0, exif)
+
+      self.saveCrop(img.crop((0, 0, newsize, newsize)), imagePath, 1, exif)
+      self.saveCrop(img.crop((size - newsize, 0, size, newsize)), imagePath, 2, exif)
+      self.saveCrop(img.crop((0, size - newsize, newsize, size)), imagePath, 3, exif)
+      self.saveCrop(img.crop((size - newsize, size - newsize, size, size)), imagePath, 4, exif)
+
+      self.saveCrop(img.crop((offset2, 0, offset2 + newsize2, newsize2)), imagePath, 5, exif)
+      self.saveCrop(img.crop((offset2, size - newsize2, offset2 + newsize2, size)), imagePath, 6, exif)
+
+  def saveCrop (self, cropped, imagePath, i, exif):
+    result = None
+    newFileFolder = os.path.dirname(imagePath)
+    oldFileName = os.path.basename(imagePath)
+    extIdx = oldFileName.rindex('.')
+    fileExt = oldFileName[extIdx+1:]
+    idx = ''
+    try:
+      val = int(i)
+      idx = (3 - len(str(val+1)))*'0' + str(val+1)
+    except ValueError:
+      idx = str(i)
+    newFileName = oldFileName[0:extIdx] + '_' + idx + '.' + fileExt
+    newFile = os.path.join(newFileFolder, newFileName)
+    result = newFile
+    if exif is None:
+      cropped.save(newFile, "jpeg", quality=100, optimize=True, progressive=True)
+    else:
+      cropped.save(newFile, "jpeg", quality=100, optimize=True, progressive=True, exif=exif)
+    return result
+
+  def cropAllSquaresHorizontal (self, img, imagePath):
+    exif = img.info['exif'] if 'exif' in img.info else None
+    size = img.height
+    numSplits = int(img.width / size) + 1
+    offset = size - int(img.width / numSplits)
+
+    face = self.detectBoxFaces1Head(imagePath)
+    if face is not None:
+      pivotX = int(face.width / 2) + face.left
+      pivotY = face.top + face.height
+      left = pivotX - face.width
+      top = pivotY - int(1.5*face.height)
+      right = pivotX + face.width
+      bottom = pivotY + int(1.5*face.height)
+      newFile = self.saveCrop(img.crop((left, top, right, bottom)), imagePath, 'face', exif)
+      self.cropAgainMoreSquares(newFile)
+
+    left = int((img.width - size)/2)
+    newFile = self.saveCrop(img.crop((left, 0, left + size, size)), imagePath, 0, exif)
+    self.cropAgainMoreSquares(newFile)
+
+    start = 0
+    for i in range(0, numSplits):
+      if i > 0:
+        start += size - offset
+        start = img.width - size if (start + size) > img.width else start
+      cropped = img.crop((start, 0, start + size, size))
+
+      newFile = self.saveCrop(cropped, imagePath, i + 1, exif)
+      self.cropAgainMoreSquares(newFile)
+
+  def cropAllSquaresVertical (self, img, imagePath):
+    exif = img.info['exif'] if 'exif' in img.info else None
+    size = img.width
+    numSplits = int(img.height / size) + 1
+    offset = size - int(img.height / numSplits)
+
+    top = int((img.height - size)/2)
+    newFile = self.saveCrop(img.crop((0, top, size, top + size)), imagePath, 0, exif)
+    self.cropAgainMoreSquares(newFile)
+
+    start = 0
+    for i in range(0, numSplits):
+      if i > 0:
+        start += size - offset
+        start = img.height - size if (start + size) > img.height else start
+      cropped = img.crop((0, start, size, start + size))
+
+      newFile = self.saveCrop(cropped, imagePath, i + 1, exif)
+      self.cropAgainMoreSquares(newFile)
+
+  def cropAllSquares (self, imagePath):
+    original = Image.open(imagePath)
+    imgWidth = original.width
+    imgHeight = original.height
+    if imgWidth != imgHeight:
+      if imgWidth > imgHeight:
+        self.cropAllSquaresHorizontal(original, imagePath)
+      else:
+        self.cropAllSquaresVertical(original, imagePath)
+
+  def cropFolderAllSquares (self, folder):
+    files = os.listdir(folder)
+    for filename in files:
+      if filename.endswith(".png") or filename.endswith(".jpg"):
+        fullpath = os.path.join(folder, filename)
+        self.cropAllSquares(fullpath)
 
 
 
